<template>
  <div>
    <list-condition-template ref="table" :isExistBtn="true" :form="listQuery" :formLabel="formLabel"
                             :tableData="tableData" :total="total"
                             @page-info-change="handlePageInfoChange">
      <template slot="otherElement">
        <el-col class="formLayout" :xs='12' :sm='12' :md='12' :lg='6' :offset="0"
                style="display: flex;">
          <el-form-item label="会员等级:" style="flex-grow:1;" prop="memberLevelName">
            <el-select placeholder="请选择会员等级" style="width:calc(100% - 72px);"
                       v-model="listQuery.memberLevelName" clearable>
              <el-option v-for="item in levelArray" :key="item.memberLevelId"
                         :value="item.memberLevelName" :label="item.memberLevelName"></el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="24" :offset="0" class="buttonPosition">
          <el-button size="mini" type="primary" @click="queryData">查询</el-button>
          <el-button size="mini" @click="resetQuery">重置</el-button>
        </el-col>
      </template>
      <template slot="operationSection">
        <el-button size="mini" type="warning" @click="importMemberInfo">导入</el-button>
        <el-button size="mini" @click="downTemplate">下载模板</el-button>
      </template>
      <template slot="columns">
        <el-table-column label="会员账号" prop="memberName" width="160px" show-overflow-tooltip>
        </el-table-column>
        <el-table-column label="会员昵称" prop="memberNickName" width="160px" show-overflow-tooltip>
          <template slot-scope="scope">
            {{scope.row.memberNickName ? scope.row.memberNickName : '-'}}
          </template>
        </el-table-column>
        <el-table-column label="会员等级" prop="memberLevelName">
          <template slot-scope="scope">
            {{scope.row.memberLevelName ? scope.row.memberLevelName : '-'}}
          </template>
        </el-table-column>
        <el-table-column label="会员积分" prop="memberIntegral"></el-table-column>
        <el-table-column label="经验值" prop="empiricalNowValue"></el-table-column>
        <el-table-column label="手机号码" prop="memberPhone" width="180px"></el-table-column>
        <el-table-column label="注册时间" prop="regTime" width="180px"></el-table-column>
        <el-table-column label="会员状态" prop="state">
          <template slot-scope="scope">
            {{getArrayLable(stateArray,scope.row.state)}}
          </template>
        </el-table-column>
        <el-table-column label="会员来源" prop="state">
          <template slot-scope="scope">
            {{scope.row.memberSource?getArrayLable(memberSource,scope.row.memberSource):'APP'}}
          </template>
        </el-table-column>
        <el-table-column label="操作" :width="`${(2 * $store.getters.colSize)+20}px`">
          <template slot-scope="scope">
            <wly-btn @click="lookInfo(scope.row)">详情</wly-btn>
            <wly-btn :type="'warning'" @click="editInfo(scope.row)">状态修改</wly-btn>
          </template>
        </el-table-column>
      </template>
    </list-condition-template>
    <el-dialog :visible.sync="dialogVisible" :title="title" :close-on-click-modal="false"
               :modal-append-to-body="false" width="40%">
      <el-form size="mini" v-show="isUpdate" ref="form" :model="form" label-width="120px"
               class="detailsInfo">
        <el-form-item label="会员状态:" prop="state" :rules="{required: true, message: '请选择会员状态'}">
          <el-select placeholder="请选择会员状态" v-model="form.state" clearable>
            <el-option v-for="item in stateArray" :key="item.id" :value="item.id"
                       :label="item.name"></el-option>
          </el-select>
        </el-form-item>
        <!-- <el-form-item label="原因" prop="reason" v-if="form.state === '3'" :rules="[{required: true, message: '请输入原因'},{max: 200, message: '原因最多只能输入 200 个字'}]">
                     <el-input type="textarea" v-model="form.reason" placeholder="请输入原因"  :autosize="{minRows:2,maxRows:6}"></el-input>
                </el-form-item> -->
      </el-form>
      <member-info v-show="!isUpdate" :form='form'></member-info>
      <div slot="footer" class="dialog-footer">
        <el-button size="mini" type="primary" v-show="isUpdate" :loading="loading" @click="submit">
          保存</el-button>
        <el-button size="mini" @click="dialogVisible=false">关闭</el-button>
      </div>
    </el-dialog>
    <el-dialog :visible.sync="importDialogVisible" title="导入" :close-on-click-modal="false"
               :modal-append-to-body="false" width="450px">
      <el-form ref="form" size="mini">
        <el-upload class="upload-demo" action="api" ref="upload" :limit="1" :accept="'.xlsx, .xls'"
                   :http-request="handleRequrst" :auto-upload="false" :file-list="fileList" drag>
          <i class="el-icon-upload"></i>
          <div class="el-upload__text">将文件拖到此处，或<em>点击上传</em></div>
          <div class="el-upload__tip" slot="tip">只能上传一个文件，且文件格式只支持.xlsx, .xls文件</div>
        </el-upload>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" size="mini" :loading="loading" @click="submitImport">确定
        </el-button>
        <el-button size="mini" @click="importDialogVisible=false">取消</el-button>
      </div>
    </el-dialog>
  </div>
</template>
<script>
import memberInfoApi from '@/api/member/memberInfo'
import memberInfo from '@/views/memberMgt/memberInfoList/info.vue'
import { objectCopy } from '@/utils/objectCopyHelper'
import memberLevelApi from '@/api/member/memberLevel'
import { getArrayLable } from '@/utils/getArrayLable'
import { downloadFile } from '@/utils/downloadFile'

var _this = null
const stateArray = [
  // {
  //   id: '0',
  //   name: '注销'
  // },
  {
    id: '1',
    name: '启用'
  },
  // {
  //   id: '2',
  //   name: '禁用'
  // },
  {
    id: '3',
    name: '冻结'
  }
]
var memberSource = [
  {
    id: 'WLY',
    name: 'APP'
  },
  {
    id: 'YDJS',
    name: '缘定晶生'
  },
  {
    id: 'YDJS_YYS',
    name: '缘定晶生运营商'
  }
]
export default {
  components: { memberInfo },
  data() {
    return {
      listQuery: {
        memberNickName: null,
        memberName: null,
        startTime: null,
        state: null,
        memberLevelName: null,
        endTime: null,
        memberSource: null
      },
      formLabel: [
        {
          model: 'startTime',
          label: '注册时间',
          type: 'date',
          pickerOptions: {
            disabledDate(time) {
              return _this.listQuery.endTime && time.getTime() >= new Date(_this.listQuery.endTime).getTime() + 86400000
            }
          },
          timeClass: 'start-time-style'
        },
        {
          model: 'endTime',
          label: '-',
          customLabel: '注册时间',
          type: 'date',
          valueFormat: 'yyyy-MM-dd 23:59:59',
          labelWidth: '20px',
          pickerOptions: {
            disabledDate(time) {
              return _this.listQuery.startTime && time.getTime() <= new Date(_this.listQuery.startTime).getTime() - 86400000
            }
          },
          timeClass: 'end-time-style'
        },
        {
          model: 'memberNickName',
          label: '会员昵称',
          type: 'input'
        },
        {
          model: 'memberName',
          label: '会员账号',
          type: 'input'
        },
        {
          model: 'state',
          label: '会员状态',
          type: 'select',
          opts: stateArray
        },
        {
          model: 'memberSource',
          label: '会员来源',
          type: 'select',
          opts: memberSource
        }
      ],
      tableData: [],
      show: false,
      title: null,
      row: {},
      dialogVisible: false,
      form: {},
      total: 0,
      isUpdate: false,
      loading: false,
      levelArray: [],
      fileList: [],
      importDialogVisible: false,
      stateArray,
      memberSource
    }
  },
  created() {
    this.queryLevelList() // 查询等级
    _this = this
  },
  /*
     * 数据变化后刷新列表
   */
  activated() {
    this.queryList(this.$refs.table.getPageInfo())
  },
  methods: {
    // 下载模板
    async downTemplate() {
      const config = {
        url: 'awl-member-service/member/download/demoExcel',
        data: null,
        fileName: '会员导入模板',
        Method: 'get',
        type: '.xlsx'
      }
      const res = await downloadFile(config)
      if (res) {
        this.percentage = 100
        this.isLoading = false
      } else {
        this.percentage = 100
        this.isLoading = false
      }
    },
    // 手动上传文件
    async handleRequrst(param) {
      this.loading = true
      const formData = new FormData()
      formData.append('file', param.file)
      try {
        const res = await memberInfoApi.importMember(formData)
        if (res.code === '0') {
          this.loading = false
          this.$message.success('导入成功！')
          this.fileList = []
          this.$refs.table.reloadCurrent()
          this.importDialogVisible = false
        } else {
          this.loading = false
          this.fileList = []
        }
      } catch (error) {
        this.fileList = []
        this.$message.error('上传文件失败！请重新上传')
        this.loading = false
      }
    },
    // 打开导入三方系统会员信息窗口
    importMemberInfo() {
      this.importDialogVisible = true
    },
    // 导入三方系统会员信息
    submitImport() {
      this.$refs.upload.submit()
    },
    /**
       * '分页信息改变时查询列表
       */
    handlePageInfoChange(pageInfo) {
      this.queryList(pageInfo)
    },

    /**
     * 重置
     */
    resetQuery() {
      this.$refs.table.reloadCurrent()
    },
    /**
     * 点击查询按钮
     */
    queryData() {
      this.$refs.table.changeCondition()
    },
    /**
     * 查询等级
     */
    queryLevelList() {
      const query = {
        pageNum: 1,
        pageSize: 100
      }
      memberLevelApi.getList(query).then(res => {
        if (res.data) {
          this.levelArray = res.data.list
        }
      })
    },
    /**
       * 修改会员状态
       */
    submit() {
      this.loading = true
      this.$refs.form.validate().then(res => {
        memberInfoApi.updateState(this.form).then(res => {
          if (res.data) {
            this.dialogVisible = false
            this.$message({
              message: '状态修改成功',
              type: 'success'
            })
            this.row.state = this.form.state
          }
          this.loading = false
        }).catch(() => {
          this.loading = false
        })
      }).catch(() => {
        this.loading = false
      })
    },
    /**
     * 获取数组的label
     */
    getArrayLable,
    /**
     * 查看详情
     */
    lookInfo(row) {
      this.isUpdate = false
      this.dialogVisible = true
      row.stateName = getArrayLable(this.stateArray, row.state)
      this.form = row
      this.title = '会员详情'
    },
    /**
     * 修改
     */
    editInfo(row) {
      this.title = '会员状态修改'
      this.dialogVisible = true
      this.isUpdate = true
      this.form = objectCopy(row)
      this.row = row
    },
    /**
     * 查询列表
     */
    queryList(pageInfo = { pageNum: 1, pageSize: 10 }) {
      this.listQuery.state = this.listQuery.state === '' ? null : this.listQuery.state
      for (const key in this.listQuery) {
        if (!this.listQuery[key]) {
          this.listQuery[key] = null
        }
      }
      memberInfoApi.getList({ ...this.listQuery, ...pageInfo }).then(res => {
        if (res.data) {
          this.tableData = res.data.list
          this.total = res.data.total
        }
      })
    }
  }
}
</script>
